# Spine Engine

[![Python](https://img.shields.io/badge/python-3.7%20|%203.8-blue.svg)](https://www.python.org/downloads/release/python-379/)
[![Unit tests](https://github.com/Spine-project/spine-engine/workflows/Unit%20tests/badge.svg)](https://github.com/Spine-project/spine-engine/actions?query=workflow%3A"Unit+tests")
[![codecov](https://codecov.io/gh/Spine-project/spine-engine/branch/master/graph/badge.svg)](https://codecov.io/gh/Spine-project/spine-engine)

A Python package to coordinate the execution of [Spine Toolbox](https://github.com/Spine-project/Spine-Toolbox) workflows.

## License

Spine Engine is released under the GNU Lesser General Public License (LGPL) license. All accompanying
documentation and manual are released under the [Creative Commons BY-SA 4.0 license](https://creativecommons.org/licenses/by-sa/4.0/).

## Getting started

### Installation

To install Spine Engine into an existing Python environment, run

    $ pip install spine_engine

### Dependencies

Spine Engine installation will install [dagster](https://dagster.readthedocs.io/en/master/index.html).